@@ -17,7 +17,8 @@ class TAuth(TokenAuth):
 
 class Auth(BasicAuth):
     def check_auth(self, username, password, allowed_roles, resource):
-        print ("resource:",resource)
+        print username
+        self.user_id = username
         return username == 'token'
         #return username == 'admin' and password == 'secret'
 
@@ -61,7 +62,7 @@ def posting_r(documents):
     print ("posting to resource contacts")
 
 
-app = Eve(validator=Validator, redis=redis)
+app = Eve(validator=Validator, redis=redis, auth=Auth)
 #app.config['DOMAIN']['contacts']['auth_username_field'] = 'name'
 #app.on_get_contacts += resource_gotit
 #app.on_get += gotit
